package
Version:
v0.0.0-...-ac52da4
Opens a new window with list of versions in this module.
Published: Jan 31, 2025
License: AGPL-3.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Abuser struct {
Name string `json:"name"`
Aliases []string `json:"aliases"`
Accusations []Accusation `json:"accusations"`
}
type Accusation struct {
Text string `json:"accusation"`
Sources []Source `json:"sources"`
}
type Source struct {
Title string `json:"title"`
Format string `json:"format"`
URL string `json:"source"`
Paywall bool `json:"paywall,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.